# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/views.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/views.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bprotos/model/v1/views.proto\x12\x08v1.model\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fprotos/model/v1/datapoint.proto\x1a\x1cgoogle/protobuf/struct.proto\"6\n\rViewsMetadata\x12%\n\x05views\x18\x01 \x03(\x0b\x32\x16.v1.model.ViewMetadata\"\xc8\x04\n\x0cViewMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x04tags\x18\x02 \x03(\x0b\x32 .v1.model.ViewMetadata.TagsEntry\x12\x16\n\x0eorganizationId\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x1a\n\x12showOnSingleDevice\x18\x07 \x01(\x08\x12\x19\n\x11showOnMultiDevice\x18\x08 \x01(\x08\x12\x14\n\x0cshowOnTeleop\x18\t \x01(\x08\x12\x17\n\x0fshowOnAnalytics\x18\n \x01(\x08\x12\x14\n\x0cshowTimeline\x18\x0b \x01(\x08\x12 \n\x06\x66ilter\x18\x0c \x01(\x0b\x32\x10.v1.model.Filter\x12\'\n\x06layout\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nlayoutType\x18\x0e \x01(\t\x12\x32\n\rconfiguration\x18\x0f \x03(\x0b\x32\x1b.v1.model.ViewConfiguration\x12\x14\n\x0csmartFleetId\x18\x10 \x01(\t\x12\r\n\x05index\x18\x11 \x01(\x03\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\nLayoutType\x12\r\n\tDASHBOARD\x10\x00\x12\x0b\n\x07OBSERVE\x10\x01\x12\x0e\n\nFULLSCREEN\x10\x02\x12\r\n\tANALYTICS\x10\x03\x12\n\n\x06TELEOP\x10\x04\"\x94\x02\n\x06\x46ilter\x12(\n\x04tags\x18\x01 \x03(\x0b\x32\x1a.v1.model.Filter.TagsEntry\x12\r\n\x05names\x18\x02 \x03(\t\x12\r\n\x05types\x18\x03 \x03(\t\x12\x11\n\tdeviceIds\x18\x04 \x03(\t\x12.\n\x07notTags\x18\x05 \x03(\x0b\x32\x1d.v1.model.Filter.NotTagsEntry\x12\x10\n\x08notNames\x18\x06 \x03(\t\x12\x10\n\x08\x61gentIds\x18\x07 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cNotTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x11ViewConfiguration\x12\x12\n\nstreamName\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\rconfiguration\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_datapoint__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])



_VIEWMETADATA_LAYOUTTYPE = _descriptor.EnumDescriptor(
  name='LayoutType',
  full_name='v1.model.ViewMetadata.LayoutType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DASHBOARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSERVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULLSCREEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANALYTICS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELEOP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=695,
  serialized_end=778,
)
_sym_db.RegisterEnumDescriptor(_VIEWMETADATA_LAYOUTTYPE)


_VIEWSMETADATA = _descriptor.Descriptor(
  name='ViewsMetadata',
  full_name='v1.model.ViewsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='views', full_name='v1.model.ViewsMetadata.views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=191,
)


_VIEWMETADATA_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.ViewMetadata.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.ViewMetadata.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.ViewMetadata.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=693,
)

_VIEWMETADATA = _descriptor.Descriptor(
  name='ViewMetadata',
  full_name='v1.model.ViewMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.ViewMetadata.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.ViewMetadata.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organizationId', full_name='v1.model.ViewMetadata.organizationId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.ViewMetadata.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='v1.model.ViewMetadata.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='v1.model.ViewMetadata.url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showOnSingleDevice', full_name='v1.model.ViewMetadata.showOnSingleDevice', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showOnMultiDevice', full_name='v1.model.ViewMetadata.showOnMultiDevice', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showOnTeleop', full_name='v1.model.ViewMetadata.showOnTeleop', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showOnAnalytics', full_name='v1.model.ViewMetadata.showOnAnalytics', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='showTimeline', full_name='v1.model.ViewMetadata.showTimeline', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='v1.model.ViewMetadata.filter', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layout', full_name='v1.model.ViewMetadata.layout', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layoutType', full_name='v1.model.ViewMetadata.layoutType', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='v1.model.ViewMetadata.configuration', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smartFleetId', full_name='v1.model.ViewMetadata.smartFleetId', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='v1.model.ViewMetadata.index', index=16,
      number=17, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VIEWMETADATA_TAGSENTRY, ],
  enum_types=[
    _VIEWMETADATA_LAYOUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=778,
)


_FILTER_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.Filter.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.Filter.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.Filter.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=693,
)

_FILTER_NOTTAGSENTRY = _descriptor.Descriptor(
  name='NotTagsEntry',
  full_name='v1.model.Filter.NotTagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.Filter.NotTagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.Filter.NotTagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1057,
)

_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='v1.model.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.Filter.tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='v1.model.Filter.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types', full_name='v1.model.Filter.types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceIds', full_name='v1.model.Filter.deviceIds', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notTags', full_name='v1.model.Filter.notTags', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notNames', full_name='v1.model.Filter.notNames', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agentIds', full_name='v1.model.Filter.agentIds', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILTER_TAGSENTRY, _FILTER_NOTTAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=1057,
)


_VIEWCONFIGURATION = _descriptor.Descriptor(
  name='ViewConfiguration',
  full_name='v1.model.ViewConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamName', full_name='v1.model.ViewConfiguration.streamName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='v1.model.ViewConfiguration.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='v1.model.ViewConfiguration.configuration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1059,
  serialized_end=1160,
)

_VIEWSMETADATA.fields_by_name['views'].message_type = _VIEWMETADATA
_VIEWMETADATA_TAGSENTRY.containing_type = _VIEWMETADATA
_VIEWMETADATA.fields_by_name['tags'].message_type = _VIEWMETADATA_TAGSENTRY
_VIEWMETADATA.fields_by_name['filter'].message_type = _FILTER
_VIEWMETADATA.fields_by_name['layout'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_VIEWMETADATA.fields_by_name['configuration'].message_type = _VIEWCONFIGURATION
_VIEWMETADATA_LAYOUTTYPE.containing_type = _VIEWMETADATA
_FILTER_TAGSENTRY.containing_type = _FILTER
_FILTER_NOTTAGSENTRY.containing_type = _FILTER
_FILTER.fields_by_name['tags'].message_type = _FILTER_TAGSENTRY
_FILTER.fields_by_name['notTags'].message_type = _FILTER_NOTTAGSENTRY
_VIEWCONFIGURATION.fields_by_name['configuration'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['ViewsMetadata'] = _VIEWSMETADATA
DESCRIPTOR.message_types_by_name['ViewMetadata'] = _VIEWMETADATA
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['ViewConfiguration'] = _VIEWCONFIGURATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ViewsMetadata = _reflection.GeneratedProtocolMessageType('ViewsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _VIEWSMETADATA,
  '__module__' : 'protos.model.v1.views_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ViewsMetadata)
  })
_sym_db.RegisterMessage(ViewsMetadata)

ViewMetadata = _reflection.GeneratedProtocolMessageType('ViewMetadata', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _VIEWMETADATA_TAGSENTRY,
    '__module__' : 'protos.model.v1.views_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.ViewMetadata.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _VIEWMETADATA,
  '__module__' : 'protos.model.v1.views_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ViewMetadata)
  })
_sym_db.RegisterMessage(ViewMetadata)
_sym_db.RegisterMessage(ViewMetadata.TagsEntry)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILTER_TAGSENTRY,
    '__module__' : 'protos.model.v1.views_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.Filter.TagsEntry)
    })
  ,

  'NotTagsEntry' : _reflection.GeneratedProtocolMessageType('NotTagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILTER_NOTTAGSENTRY,
    '__module__' : 'protos.model.v1.views_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.Filter.NotTagsEntry)
    })
  ,
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'protos.model.v1.views_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Filter)
  })
_sym_db.RegisterMessage(Filter)
_sym_db.RegisterMessage(Filter.TagsEntry)
_sym_db.RegisterMessage(Filter.NotTagsEntry)

ViewConfiguration = _reflection.GeneratedProtocolMessageType('ViewConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _VIEWCONFIGURATION,
  '__module__' : 'protos.model.v1.views_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ViewConfiguration)
  })
_sym_db.RegisterMessage(ViewConfiguration)


DESCRIPTOR._options = None
_VIEWMETADATA_TAGSENTRY._options = None
_FILTER_TAGSENTRY._options = None
_FILTER_NOTTAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="NodeInfo")


@attr.s(auto_attribs=True)
class NodeInfo:
    """
    Attributes:
        hostname (Union[Unset, str]):
        machineid (Union[Unset, str]):
        timezone (Union[Unset, str]):
    """

    hostname: Union[Unset, str] = UNSET
    machineid: Union[Unset, str] = UNSET
    timezone: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        hostname = self.hostname
        machineid = self.machineid
        timezone = self.timezone

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if hostname is not UNSET:
            field_dict["hostname"] = hostname
        if machineid is not UNSET:
            field_dict["machineid"] = machineid
        if timezone is not UNSET:
            field_dict["timezone"] = timezone

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        hostname = d.pop("hostname", UNSET)

        machineid = d.pop("machineid", UNSET)

        timezone = d.pop("timezone", UNSET)

        node_info = cls(
            hostname=hostname,
            machineid=machineid,
            timezone=timezone,
        )

        node_info.additional_properties = d
        return node_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="PhysicalRequestData")


@attr.s(auto_attribs=True)
class PhysicalRequestData:
    """
    Attributes:
        reason (str):
        metadata (Union[Unset, Any]):
        start_time (Union[Unset, datetime.datetime]):
        end_time (Union[Unset, datetime.datetime]):
    """

    reason: str
    metadata: Union[Unset, Any] = UNSET
    start_time: Union[Unset, datetime.datetime] = UNSET
    end_time: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        reason = self.reason
        metadata = self.metadata
        start_time: Union[Unset, str] = UNSET
        if not isinstance(self.start_time, Unset):
            start_time = self.start_time.isoformat()

        end_time: Union[Unset, str] = UNSET
        if not isinstance(self.end_time, Unset):
            end_time = self.end_time.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "reason": reason,
            }
        )
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if start_time is not UNSET:
            field_dict["startTime"] = start_time
        if end_time is not UNSET:
            field_dict["endTime"] = end_time

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        reason = d.pop("reason")

        metadata = d.pop("metadata", UNSET)

        _start_time = d.pop("startTime", UNSET)
        start_time: Union[Unset, datetime.datetime]
        if isinstance(_start_time, Unset):
            start_time = UNSET
        else:
            start_time = isoparse(_start_time)

        _end_time = d.pop("endTime", UNSET)
        end_time: Union[Unset, datetime.datetime]
        if isinstance(_end_time, Unset):
            end_time = UNSET
        else:
            end_time = isoparse(_end_time)

        physical_request_data = cls(
            reason=reason,
            metadata=metadata,
            start_time=start_time,
            end_time=end_time,
        )

        physical_request_data.additional_properties = d
        return physical_request_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/intervention.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2
from formant.protos.model.v1 import event_pb2 as protos_dot_model_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/intervention.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"protos/model/v1/intervention.proto\x12\x08v1.model\x1a\x1bprotos/model/v1/media.proto\x1a\x1bprotos/model/v1/event.proto\"\x9c\x03\n\x13InterventionRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12$\n\x08severity\x18\x03 \x01(\x0e\x32\x12.v1.model.Severity\x12\x37\n\x11selection_request\x18\x04 \x01(\x0b\x32\x1a.v1.model.SelectionRequestH\x00\x12\x35\n\x10labeling_request\x18\x05 \x01(\x0b\x32\x19.v1.model.LabelingRequestH\x00\x12\x31\n\x0eteleop_request\x18\x08 \x01(\x0b\x32\x17.v1.model.TeleopRequestH\x00\x12\x35\n\x04tags\x18\x06 \x03(\x0b\x32\'.v1.model.InterventionRequest.TagsEntry\x12\x31\n\tresponses\x18\x07 \x03(\x0b\x32\x1e.v1.model.InterventionResponse\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x64\x61ta\"\xfa\x01\n\x14InterventionResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12\x39\n\x12selection_response\x18\x04 \x01(\x0b\x32\x1b.v1.model.SelectionResponseH\x00\x12\x37\n\x11labeling_response\x18\x05 \x01(\x0b\x32\x1a.v1.model.LabelingResponseH\x00\x12\x33\n\x0fteleop_response\x18\x06 \x01(\x0b\x32\x18.v1.model.TeleopResponseH\x00\x42\x06\n\x04\x64\x61ta\",\n\x05Label\x12\r\n\x05value\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\"D\n\x0eLabeledPolygon\x12\"\n\x08vertices\x18\x01 \x03(\x0b\x32\x10.v1.model.Vertex\x12\x0e\n\x06labels\x18\x02 \x03(\t\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x9e\x01\n\x0fLabelingRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0binstruction\x18\x02 \x01(\t\x12\x1e\n\x05image\x18\x03 \x01(\x0b\x32\x0f.v1.model.Image\x12\x1f\n\x06labels\x18\x04 \x03(\x0b\x32\x0f.v1.model.Label\x12&\n\x04hint\x18\x05 \x03(\x0b\x32\x18.v1.model.LabeledPolygon\";\n\x10LabelingResponse\x12\'\n\x05value\x18\x01 \x03(\x0b\x32\x18.v1.model.LabeledPolygon\"\x7f\n\x10SelectionRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12 \n\x05image\x18\x02 \x01(\x0b\x32\x0f.v1.model.ImageH\x00\x12\x13\n\x0binstruction\x18\x03 \x01(\t\x12\x0f\n\x07options\x18\x04 \x03(\t\x12\x0c\n\x04hint\x18\x05 \x01(\rB\x06\n\x04\x64\x61ta\"\"\n\x11SelectionResponse\x12\r\n\x05value\x18\x01 \x01(\r\"$\n\rTeleopRequest\x12\x13\n\x0binstruction\x18\x01 \x01(\t\".\n\x0eTeleopResponse\x12\r\n\x05state\x18\x01 \x01(\t\x12\r\n\x05notes\x18\x02 \x01(\tB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_media__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_event__pb2.DESCRIPTOR,])




_INTERVENTIONREQUEST_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.InterventionRequest.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.InterventionRequest.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.InterventionRequest.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=511,
)

_INTERVENTIONREQUEST = _descriptor.Descriptor(
  name='InterventionRequest',
  full_name='v1.model.InterventionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.InterventionRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.InterventionRequest.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='v1.model.InterventionRequest.severity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selection_request', full_name='v1.model.InterventionRequest.selection_request', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labeling_request', full_name='v1.model.InterventionRequest.labeling_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teleop_request', full_name='v1.model.InterventionRequest.teleop_request', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.InterventionRequest.tags', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='responses', full_name='v1.model.InterventionRequest.responses', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INTERVENTIONREQUEST_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.InterventionRequest.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=107,
  serialized_end=519,
)


_INTERVENTIONRESPONSE = _descriptor.Descriptor(
  name='InterventionResponse',
  full_name='v1.model.InterventionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.InterventionResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='v1.model.InterventionResponse.request_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.InterventionResponse.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selection_response', full_name='v1.model.InterventionResponse.selection_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labeling_response', full_name='v1.model.InterventionResponse.labeling_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teleop_response', full_name='v1.model.InterventionResponse.teleop_response', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.InterventionResponse.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=522,
  serialized_end=772,
)


_LABEL = _descriptor.Descriptor(
  name='Label',
  full_name='v1.model.Label',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.Label.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='v1.model.Label.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=818,
)


_LABELEDPOLYGON = _descriptor.Descriptor(
  name='LabeledPolygon',
  full_name='v1.model.LabeledPolygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='v1.model.LabeledPolygon.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='v1.model.LabeledPolygon.labels', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=820,
  serialized_end=888,
)


_VERTEX = _descriptor.Descriptor(
  name='Vertex',
  full_name='v1.model.Vertex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='v1.model.Vertex.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='v1.model.Vertex.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=920,
)


_LABELINGREQUEST = _descriptor.Descriptor(
  name='LabelingRequest',
  full_name='v1.model.LabelingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='v1.model.LabelingRequest.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instruction', full_name='v1.model.LabelingRequest.instruction', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='v1.model.LabelingRequest.image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='v1.model.LabelingRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='v1.model.LabelingRequest.hint', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1081,
)


_LABELINGRESPONSE = _descriptor.Descriptor(
  name='LabelingResponse',
  full_name='v1.model.LabelingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.LabelingResponse.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1083,
  serialized_end=1142,
)


_SELECTIONREQUEST = _descriptor.Descriptor(
  name='SelectionRequest',
  full_name='v1.model.SelectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='v1.model.SelectionRequest.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='v1.model.SelectionRequest.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instruction', full_name='v1.model.SelectionRequest.instruction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='v1.model.SelectionRequest.options', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hint', full_name='v1.model.SelectionRequest.hint', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.SelectionRequest.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1144,
  serialized_end=1271,
)


_SELECTIONRESPONSE = _descriptor.Descriptor(
  name='SelectionResponse',
  full_name='v1.model.SelectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.SelectionResponse.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1273,
  serialized_end=1307,
)


_TELEOPREQUEST = _descriptor.Descriptor(
  name='TeleopRequest',
  full_name='v1.model.TeleopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instruction', full_name='v1.model.TeleopRequest.instruction', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1345,
)


_TELEOPRESPONSE = _descriptor.Descriptor(
  name='TeleopResponse',
  full_name='v1.model.TeleopResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='v1.model.TeleopResponse.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notes', full_name='v1.model.TeleopResponse.notes', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1347,
  serialized_end=1393,
)

_INTERVENTIONREQUEST_TAGSENTRY.containing_type = _INTERVENTIONREQUEST
_INTERVENTIONREQUEST.fields_by_name['severity'].enum_type = protos_dot_model_dot_v1_dot_event__pb2._SEVERITY
_INTERVENTIONREQUEST.fields_by_name['selection_request'].message_type = _SELECTIONREQUEST
_INTERVENTIONREQUEST.fields_by_name['labeling_request'].message_type = _LABELINGREQUEST
_INTERVENTIONREQUEST.fields_by_name['teleop_request'].message_type = _TELEOPREQUEST
_INTERVENTIONREQUEST.fields_by_name['tags'].message_type = _INTERVENTIONREQUEST_TAGSENTRY
_INTERVENTIONREQUEST.fields_by_name['responses'].message_type = _INTERVENTIONRESPONSE
_INTERVENTIONREQUEST.oneofs_by_name['data'].fields.append(
  _INTERVENTIONREQUEST.fields_by_name['selection_request'])
_INTERVENTIONREQUEST.fields_by_name['selection_request'].containing_oneof = _INTERVENTIONREQUEST.oneofs_by_name['data']
_INTERVENTIONREQUEST.oneofs_by_name['data'].fields.append(
  _INTERVENTIONREQUEST.fields_by_name['labeling_request'])
_INTERVENTIONREQUEST.fields_by_name['labeling_request'].containing_oneof = _INTERVENTIONREQUEST.oneofs_by_name['data']
_INTERVENTIONREQUEST.oneofs_by_name['data'].fields.append(
  _INTERVENTIONREQUEST.fields_by_name['teleop_request'])
_INTERVENTIONREQUEST.fields_by_name['teleop_request'].containing_oneof = _INTERVENTIONREQUEST.oneofs_by_name['data']
_INTERVENTIONRESPONSE.fields_by_name['selection_response'].message_type = _SELECTIONRESPONSE
_INTERVENTIONRESPONSE.fields_by_name['labeling_response'].message_type = _LABELINGRESPONSE
_INTERVENTIONRESPONSE.fields_by_name['teleop_response'].message_type = _TELEOPRESPONSE
_INTERVENTIONRESPONSE.oneofs_by_name['data'].fields.append(
  _INTERVENTIONRESPONSE.fields_by_name['selection_response'])
_INTERVENTIONRESPONSE.fields_by_name['selection_response'].containing_oneof = _INTERVENTIONRESPONSE.oneofs_by_name['data']
_INTERVENTIONRESPONSE.oneofs_by_name['data'].fields.append(
  _INTERVENTIONRESPONSE.fields_by_name['labeling_response'])
_INTERVENTIONRESPONSE.fields_by_name['labeling_response'].containing_oneof = _INTERVENTIONRESPONSE.oneofs_by_name['data']
_INTERVENTIONRESPONSE.oneofs_by_name['data'].fields.append(
  _INTERVENTIONRESPONSE.fields_by_name['teleop_response'])
_INTERVENTIONRESPONSE.fields_by_name['teleop_response'].containing_oneof = _INTERVENTIONRESPONSE.oneofs_by_name['data']
_LABELEDPOLYGON.fields_by_name['vertices'].message_type = _VERTEX
_LABELINGREQUEST.fields_by_name['image'].message_type = protos_dot_model_dot_v1_dot_media__pb2._IMAGE
_LABELINGREQUEST.fields_by_name['labels'].message_type = _LABEL
_LABELINGREQUEST.fields_by_name['hint'].message_type = _LABELEDPOLYGON
_LABELINGRESPONSE.fields_by_name['value'].message_type = _LABELEDPOLYGON
_SELECTIONREQUEST.fields_by_name['image'].message_type = protos_dot_model_dot_v1_dot_media__pb2._IMAGE
_SELECTIONREQUEST.oneofs_by_name['data'].fields.append(
  _SELECTIONREQUEST.fields_by_name['image'])
_SELECTIONREQUEST.fields_by_name['image'].containing_oneof = _SELECTIONREQUEST.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['InterventionRequest'] = _INTERVENTIONREQUEST
DESCRIPTOR.message_types_by_name['InterventionResponse'] = _INTERVENTIONRESPONSE
DESCRIPTOR.message_types_by_name['Label'] = _LABEL
DESCRIPTOR.message_types_by_name['LabeledPolygon'] = _LABELEDPOLYGON
DESCRIPTOR.message_types_by_name['Vertex'] = _VERTEX
DESCRIPTOR.message_types_by_name['LabelingRequest'] = _LABELINGREQUEST
DESCRIPTOR.message_types_by_name['LabelingResponse'] = _LABELINGRESPONSE
DESCRIPTOR.message_types_by_name['SelectionRequest'] = _SELECTIONREQUEST
DESCRIPTOR.message_types_by_name['SelectionResponse'] = _SELECTIONRESPONSE
DESCRIPTOR.message_types_by_name['TeleopRequest'] = _TELEOPREQUEST
DESCRIPTOR.message_types_by_name['TeleopResponse'] = _TELEOPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InterventionRequest = _reflection.GeneratedProtocolMessageType('InterventionRequest', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INTERVENTIONREQUEST_TAGSENTRY,
    '__module__' : 'protos.model.v1.intervention_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.InterventionRequest.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _INTERVENTIONREQUEST,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.InterventionRequest)
  })
_sym_db.RegisterMessage(InterventionRequest)
_sym_db.RegisterMessage(InterventionRequest.TagsEntry)

InterventionResponse = _reflection.GeneratedProtocolMessageType('InterventionResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTERVENTIONRESPONSE,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.InterventionResponse)
  })
_sym_db.RegisterMessage(InterventionResponse)

Label = _reflection.GeneratedProtocolMessageType('Label', (_message.Message,), {
  'DESCRIPTOR' : _LABEL,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Label)
  })
_sym_db.RegisterMessage(Label)

LabeledPolygon = _reflection.GeneratedProtocolMessageType('LabeledPolygon', (_message.Message,), {
  'DESCRIPTOR' : _LABELEDPOLYGON,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.LabeledPolygon)
  })
_sym_db.RegisterMessage(LabeledPolygon)

Vertex = _reflection.GeneratedProtocolMessageType('Vertex', (_message.Message,), {
  'DESCRIPTOR' : _VERTEX,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Vertex)
  })
_sym_db.RegisterMessage(Vertex)

LabelingRequest = _reflection.GeneratedProtocolMessageType('LabelingRequest', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGREQUEST,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.LabelingRequest)
  })
_sym_db.RegisterMessage(LabelingRequest)

LabelingResponse = _reflection.GeneratedProtocolMessageType('LabelingResponse', (_message.Message,), {
  'DESCRIPTOR' : _LABELINGRESPONSE,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.LabelingResponse)
  })
_sym_db.RegisterMessage(LabelingResponse)

SelectionRequest = _reflection.GeneratedProtocolMessageType('SelectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELECTIONREQUEST,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.SelectionRequest)
  })
_sym_db.RegisterMessage(SelectionRequest)

SelectionResponse = _reflection.GeneratedProtocolMessageType('SelectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELECTIONRESPONSE,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.SelectionResponse)
  })
_sym_db.RegisterMessage(SelectionResponse)

TeleopRequest = _reflection.GeneratedProtocolMessageType('TeleopRequest', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPREQUEST,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TeleopRequest)
  })
_sym_db.RegisterMessage(TeleopRequest)

TeleopResponse = _reflection.GeneratedProtocolMessageType('TeleopResponse', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPRESPONSE,
  '__module__' : 'protos.model.v1.intervention_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.TeleopResponse)
  })
_sym_db.RegisterMessage(TeleopResponse)


DESCRIPTOR._options = None
_INTERVENTIONREQUEST_TAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



from formant.protos.model.v1 import math_pb2
from formant.sdk.agent.v1.localization.utils import validate_type, get_ros_module
from .vector3 import Vector3


class Twist:
    @classmethod
    def from_ros(cls, twist):
        msgs = get_ros_module("geometry_msgs.msg")
        validate_type(twist, msgs.Twist)
        return cls(
            linear=Vector3.from_ros(twist.linear),
            angular=Vector3.from_ros(twist.angular),
        )

    @classmethod
    def from_ros_twist_with_covariance(cls, twist):
        msgs = get_ros_module("geometry_msgs.msg")
        validate_type(twist, msgs.TwistWithCovariance)
        return cls.from_ros(twist.twist)

    def __init__(
        self,
        linear=Vector3.identity(),  # type: Vector3
        angular=Vector3.identity(),  # type: Vector3
    ):
        self.linear = linear
        self.angular = angular

    def to_proto(self):
        return math_pb2.Twist(
            linear=self.linear.to_proto(), angular=self.angular.to_proto()
        )



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.filter_ import Filter
    from ..models.view_configuration import ViewConfiguration


T = TypeVar("T", bound="PartialChannel")


@attr.s(auto_attribs=True)
class PartialChannel:
    """
    Attributes:
        organization_id (Union[Unset, str]):
        name (Union[Unset, str]):
        description (Union[Unset, str]):
        filter_ (Union[Unset, None, Filter]):
        layout (Union[Unset, Any]):
        configuration (Union[Unset, List['ViewConfiguration']]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    organization_id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    filter_: Union[Unset, None, "Filter"] = UNSET
    layout: Union[Unset, Any] = UNSET
    configuration: Union[Unset, List["ViewConfiguration"]] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        organization_id = self.organization_id
        name = self.name
        description = self.description
        filter_: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.filter_, Unset):
            filter_ = self.filter_.to_dict() if self.filter_ else None

        layout = self.layout
        configuration: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.configuration, Unset):
            configuration = []
            for configuration_item_data in self.configuration:
                configuration_item = configuration_item_data.to_dict()

                configuration.append(configuration_item)

        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if layout is not UNSET:
            field_dict["layout"] = layout
        if configuration is not UNSET:
            field_dict["configuration"] = configuration
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.filter_ import Filter
        from ..models.view_configuration import ViewConfiguration

        d = src_dict.copy()
        organization_id = d.pop("organizationId", UNSET)

        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        _filter_ = d.pop("filter", UNSET)
        filter_: Union[Unset, None, Filter]
        if _filter_ is None:
            filter_ = None
        elif isinstance(_filter_, Unset):
            filter_ = UNSET
        else:
            filter_ = Filter.from_dict(_filter_)

        layout = d.pop("layout", UNSET)

        configuration = []
        _configuration = d.pop("configuration", UNSET)
        for configuration_item_data in _configuration or []:
            configuration_item = ViewConfiguration.from_dict(configuration_item_data)

            configuration.append(configuration_item)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        partial_channel = cls(
            organization_id=organization_id,
            name=name,
            description=description,
            filter_=filter_,
            layout=layout,
            configuration=configuration,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        partial_channel.additional_properties = d
        return partial_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.device_query_type import DeviceQueryType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceQuery")


@attr.s(auto_attribs=True)
class DeviceQuery:
    """
    Attributes:
        name (Union[Unset, str]):
        query (Union[Unset, str]):
        organization_id (Union[Unset, str]):
        tags (Union[Unset, Any]):
        fleet_id (Union[Unset, None, str]):
        enabled (Union[Unset, bool]):
        fully_configured (Union[Unset, bool]):
        type (Union[Unset, DeviceQueryType]):
        count (Union[Unset, float]):
        offset (Union[Unset, float]):
        disabled_before (Union[Unset, datetime.datetime]):
    """

    name: Union[Unset, str] = UNSET
    query: Union[Unset, str] = UNSET
    organization_id: Union[Unset, str] = UNSET
    tags: Union[Unset, Any] = UNSET
    fleet_id: Union[Unset, None, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    fully_configured: Union[Unset, bool] = UNSET
    type: Union[Unset, DeviceQueryType] = UNSET
    count: Union[Unset, float] = UNSET
    offset: Union[Unset, float] = UNSET
    disabled_before: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        query = self.query
        organization_id = self.organization_id
        tags = self.tags
        fleet_id = self.fleet_id
        enabled = self.enabled
        fully_configured = self.fully_configured
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        count = self.count
        offset = self.offset
        disabled_before: Union[Unset, str] = UNSET
        if not isinstance(self.disabled_before, Unset):
            disabled_before = self.disabled_before.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if query is not UNSET:
            field_dict["query"] = query
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if tags is not UNSET:
            field_dict["tags"] = tags
        if fleet_id is not UNSET:
            field_dict["fleetId"] = fleet_id
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if fully_configured is not UNSET:
            field_dict["fullyConfigured"] = fully_configured
        if type is not UNSET:
            field_dict["type"] = type
        if count is not UNSET:
            field_dict["count"] = count
        if offset is not UNSET:
            field_dict["offset"] = offset
        if disabled_before is not UNSET:
            field_dict["disabledBefore"] = disabled_before

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        query = d.pop("query", UNSET)

        organization_id = d.pop("organizationId", UNSET)

        tags = d.pop("tags", UNSET)

        fleet_id = d.pop("fleetId", UNSET)

        enabled = d.pop("enabled", UNSET)

        fully_configured = d.pop("fullyConfigured", UNSET)

        _type = d.pop("type", UNSET)
        type: Union[Unset, DeviceQueryType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = DeviceQueryType(_type)

        count = d.pop("count", UNSET)

        offset = d.pop("offset", UNSET)

        _disabled_before = d.pop("disabledBefore", UNSET)
        disabled_before: Union[Unset, datetime.datetime]
        if isinstance(_disabled_before, Unset):
            disabled_before = UNSET
        else:
            disabled_before = isoparse(_disabled_before)

        device_query = cls(
            name=name,
            query=query,
            organization_id=organization_id,
            tags=tags,
            fleet_id=fleet_id,
            enabled=enabled,
            fully_configured=fully_configured,
            type=type,
            count=count,
            offset=offset,
            disabled_before=disabled_before,
        )

        device_query.additional_properties = d
        return device_query

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.annotation_field_values_request_tags import AnnotationFieldValuesRequestTags


T = TypeVar("T", bound="AnnotationFieldValuesRequest")


@attr.s(auto_attribs=True)
class AnnotationFieldValuesRequest:
    """
    Attributes:
        annotation_template_id (str):
        key (Any):
        tags (AnnotationFieldValuesRequestTags):
    """

    annotation_template_id: str
    key: Any
    tags: "AnnotationFieldValuesRequestTags"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        annotation_template_id = self.annotation_template_id
        key = self.key
        tags = self.tags.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "annotationTemplateId": annotation_template_id,
                "key": key,
                "tags": tags,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.annotation_field_values_request_tags import AnnotationFieldValuesRequestTags

        d = src_dict.copy()
        annotation_template_id = d.pop("annotationTemplateId")

        key = d.pop("key")

        tags = AnnotationFieldValuesRequestTags.from_dict(d.pop("tags"))

        annotation_field_values_request = cls(
            annotation_template_id=annotation_template_id,
            key=key,
            tags=tags,
        )

        annotation_field_values_request.additional_properties = d
        return annotation_field_values_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.teleop_joystick_axis_configuration_dimension import TeleopJoystickAxisConfigurationDimension
from ..types import UNSET, Unset

T = TypeVar("T", bound="TeleopJoystickAxisConfiguration")


@attr.s(auto_attribs=True)
class TeleopJoystickAxisConfiguration:
    """
    Attributes:
        dimension (Union[Unset, TeleopJoystickAxisConfigurationDimension]):
        scale (Union[Unset, float]):
        expo (Union[Unset, float]):
        gamepad_axis (Union[Unset, int]):
    """

    dimension: Union[Unset, TeleopJoystickAxisConfigurationDimension] = UNSET
    scale: Union[Unset, float] = UNSET
    expo: Union[Unset, float] = UNSET
    gamepad_axis: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        dimension: Union[Unset, str] = UNSET
        if not isinstance(self.dimension, Unset):
            dimension = self.dimension.value

        scale = self.scale
        expo = self.expo
        gamepad_axis = self.gamepad_axis

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if dimension is not UNSET:
            field_dict["dimension"] = dimension
        if scale is not UNSET:
            field_dict["scale"] = scale
        if expo is not UNSET:
            field_dict["expo"] = expo
        if gamepad_axis is not UNSET:
            field_dict["gamepadAxis"] = gamepad_axis

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _dimension = d.pop("dimension", UNSET)
        dimension: Union[Unset, TeleopJoystickAxisConfigurationDimension]
        if isinstance(_dimension, Unset):
            dimension = UNSET
        else:
            dimension = TeleopJoystickAxisConfigurationDimension(_dimension)

        scale = d.pop("scale", UNSET)

        expo = d.pop("expo", UNSET)

        gamepad_axis = d.pop("gamepadAxis", UNSET)

        teleop_joystick_axis_configuration = cls(
            dimension=dimension,
            scale=scale,
            expo=expo,
            gamepad_axis=gamepad_axis,
        )

        teleop_joystick_axis_configuration.additional_properties = d
        return teleop_joystick_axis_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class QueryAggregate(str, Enum):
    YEAR = "year"
    MONTH = "month"
    WEEK = "week"
    DAY = "day"
    VALUE_4 = "12 hours"
    VALUE_5 = "4 hours"
    HOUR = "hour"
    VALUE_7 = "30 minutes"
    VALUE_8 = "5 minutes"
    MINUTE = "minute"
    VALUE_10 = "30 seconds"
    VALUE_11 = "5 seconds"
    SECOND = "second"

    def __str__(self) -> str:
        return str(self.value)




from . import Response, EventListResponse, EventQuery, event_controller_query
from formant.sdk.cloud.v2.src.resources.resources import Resources

class Events(Resources):

    def query(self, event_query: EventQuery):
        'Get an event'
        client = self._get_client()
        response: Response[EventListResponse] = event_controller_query.sync_detailed(client=client, json_body=event_query)
        return response

    async def query_async(self, event_query: EventQuery):
        'Get an event'
        client = self._get_client()
        response: Response[EventListResponse] = (await event_controller_query.asyncio_detailed(client=client, json_body=event_query))
        return response



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="BeginUploadRequest")


@attr.s(auto_attribs=True)
class BeginUploadRequest:
    """
    Attributes:
        file_name (str):
        file_size (int):
        force_overwrite (Union[Unset, bool]):
    """

    file_name: str
    file_size: int
    force_overwrite: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        file_name = self.file_name
        file_size = self.file_size
        force_overwrite = self.force_overwrite

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "fileName": file_name,
                "fileSize": file_size,
            }
        )
        if force_overwrite is not UNSET:
            field_dict["forceOverwrite"] = force_overwrite

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        file_name = d.pop("fileName")

        file_size = d.pop("fileSize")

        force_overwrite = d.pop("forceOverwrite", UNSET)

        begin_upload_request = cls(
            file_name=file_name,
            file_size=file_size,
            force_overwrite=force_overwrite,
        )

        begin_upload_request.additional_properties = d
        return begin_upload_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.sql_column import SqlColumn


T = TypeVar("T", bound="SqlResult")


@attr.s(auto_attribs=True)
class SqlResult:
    """
    Attributes:
        rows (List[Any]):
        columns (List['SqlColumn']):
        row_count (float):
        sql_text (str):
        unit (Union[Unset, str]):
    """

    rows: List[Any]
    columns: List["SqlColumn"]
    row_count: float
    sql_text: str
    unit: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        rows = self.rows

        columns = []
        for columns_item_data in self.columns:
            columns_item = columns_item_data.to_dict()

            columns.append(columns_item)

        row_count = self.row_count
        sql_text = self.sql_text
        unit = self.unit

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "rows": rows,
                "columns": columns,
                "rowCount": row_count,
                "sqlText": sql_text,
            }
        )
        if unit is not UNSET:
            field_dict["unit"] = unit

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sql_column import SqlColumn

        d = src_dict.copy()
        rows = cast(List[Any], d.pop("rows"))

        columns = []
        _columns = d.pop("columns")
        for columns_item_data in _columns:
            columns_item = SqlColumn.from_dict(columns_item_data)

            columns.append(columns_item)

        row_count = d.pop("rowCount")

        sql_text = d.pop("sqlText")

        unit = d.pop("unit", UNSET)

        sql_result = cls(
            rows=rows,
            columns=columns,
            row_count=row_count,
            sql_text=sql_text,
            unit=unit,
        )

        sql_result.additional_properties = d
        return sql_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, cast

import attr

T = TypeVar("T", bound="LabeledPolygon")


@attr.s(auto_attribs=True)
class LabeledPolygon:
    """
    Attributes:
        vertices (List[List[Any]]):
        labels (List[str]):
    """

    vertices: List[List[Any]]
    labels: List[str]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        vertices = []
        for vertices_item_data in self.vertices:
            vertices_item = vertices_item_data

            vertices.append(vertices_item)

        labels = self.labels

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "vertices": vertices,
                "labels": labels,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        vertices = []
        _vertices = d.pop("vertices")
        for vertices_item_data in _vertices:
            vertices_item = cast(List[Any], vertices_item_data)

            vertices.append(vertices_item)

        labels = cast(List[str], d.pop("labels"))

        labeled_polygon = cls(
            vertices=vertices,
            labels=labels,
        )

        labeled_polygon.additional_properties = d
        return labeled_polygon

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.command_response_stream_type import CommandResponseStreamType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.command_response_tags import CommandResponseTags


T = TypeVar("T", bound="CommandResponse")


@attr.s(auto_attribs=True)
class CommandResponse:
    """
    Attributes:
        time (datetime.datetime):
        message (str):
        success (bool):
        reply_to_command_request_id (str):
        stream_name (Union[Unset, str]):
        stream_type (Union[Unset, CommandResponseStreamType]):
        tags (Union[Unset, CommandResponseTags]):
        canceled_at (Union[Unset, datetime.datetime]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    time: datetime.datetime
    message: str
    success: bool
    reply_to_command_request_id: str
    stream_name: Union[Unset, str] = UNSET
    stream_type: Union[Unset, CommandResponseStreamType] = UNSET
    tags: Union[Unset, "CommandResponseTags"] = UNSET
    canceled_at: Union[Unset, datetime.datetime] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        time = self.time.isoformat()

        message = self.message
        success = self.success
        reply_to_command_request_id = self.reply_to_command_request_id
        stream_name = self.stream_name
        stream_type: Union[Unset, str] = UNSET
        if not isinstance(self.stream_type, Unset):
            stream_type = self.stream_type.value

        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        canceled_at: Union[Unset, str] = UNSET
        if not isinstance(self.canceled_at, Unset):
            canceled_at = self.canceled_at.isoformat()

        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "time": time,
                "message": message,
                "success": success,
                "replyToCommandRequestId": reply_to_command_request_id,
            }
        )
        if stream_name is not UNSET:
            field_dict["streamName"] = stream_name
        if stream_type is not UNSET:
            field_dict["streamType"] = stream_type
        if tags is not UNSET:
            field_dict["tags"] = tags
        if canceled_at is not UNSET:
            field_dict["canceledAt"] = canceled_at
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.command_response_tags import CommandResponseTags

        d = src_dict.copy()
        time = isoparse(d.pop("time"))

        message = d.pop("message")

        success = d.pop("success")

        reply_to_command_request_id = d.pop("replyToCommandRequestId")

        stream_name = d.pop("streamName", UNSET)

        _stream_type = d.pop("streamType", UNSET)
        stream_type: Union[Unset, CommandResponseStreamType]
        if isinstance(_stream_type, Unset):
            stream_type = UNSET
        else:
            stream_type = CommandResponseStreamType(_stream_type)

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, CommandResponseTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = CommandResponseTags.from_dict(_tags)

        _canceled_at = d.pop("canceledAt", UNSET)
        canceled_at: Union[Unset, datetime.datetime]
        if isinstance(_canceled_at, Unset):
            canceled_at = UNSET
        else:
            canceled_at = isoparse(_canceled_at)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        command_response = cls(
            time=time,
            message=message,
            success=success,
            reply_to_command_request_id=reply_to_command_request_id,
            stream_name=stream_name,
            stream_type=stream_type,
            tags=tags,
            canceled_at=canceled_at,
            created_at=created_at,
            updated_at=updated_at,
        )

        command_response.additional_properties = d
        return command_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.suggestion_structure_schema import SuggestionStructureSchema


T = TypeVar("T", bound="ThinkingRequest")


@attr.s(auto_attribs=True)
class ThinkingRequest:
    """
    Attributes:
        actions (List['SuggestionStructureSchema']):
        prompt (str):
        facts (Union[Unset, List[str]]):
        principles (Union[Unset, List[str]]):
        goals (Union[Unset, List[str]]):
        model (Union[Unset, str]):
    """

    actions: List["SuggestionStructureSchema"]
    prompt: str
    facts: Union[Unset, List[str]] = UNSET
    principles: Union[Unset, List[str]] = UNSET
    goals: Union[Unset, List[str]] = UNSET
    model: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        actions = []
        for actions_item_data in self.actions:
            actions_item = actions_item_data.to_dict()

            actions.append(actions_item)

        prompt = self.prompt
        facts: Union[Unset, List[str]] = UNSET
        if not isinstance(self.facts, Unset):
            facts = self.facts

        principles: Union[Unset, List[str]] = UNSET
        if not isinstance(self.principles, Unset):
            principles = self.principles

        goals: Union[Unset, List[str]] = UNSET
        if not isinstance(self.goals, Unset):
            goals = self.goals

        model = self.model

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "actions": actions,
                "prompt": prompt,
            }
        )
        if facts is not UNSET:
            field_dict["facts"] = facts
        if principles is not UNSET:
            field_dict["principles"] = principles
        if goals is not UNSET:
            field_dict["goals"] = goals
        if model is not UNSET:
            field_dict["model"] = model

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.suggestion_structure_schema import SuggestionStructureSchema

        d = src_dict.copy()
        actions = []
        _actions = d.pop("actions")
        for actions_item_data in _actions:
            actions_item = SuggestionStructureSchema.from_dict(actions_item_data)

            actions.append(actions_item)

        prompt = d.pop("prompt")

        facts = cast(List[str], d.pop("facts", UNSET))

        principles = cast(List[str], d.pop("principles", UNSET))

        goals = cast(List[str], d.pop("goals", UNSET))

        model = d.pop("model", UNSET)

        thinking_request = cls(
            actions=actions,
            prompt=prompt,
            facts=facts,
            principles=principles,
            goals=goals,
            model=model,
        )

        thinking_request.additional_properties = d
        return thinking_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/commands.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from formant.protos.model.v1 import datapoint_pb2 as protos_dot_model_dot_v1_dot_datapoint__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/commands.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eprotos/model/v1/commands.proto\x12\x08v1.model\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fprotos/model/v1/datapoint.proto\"\xa0\x01\n\x0e\x43ommandRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x0e\n\x04text\x18\x03 \x01(\tH\x00\x12\x31\n\rscrubber_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x05\x66iles\x18\x05 \x03(\x0b\x32\x12.v1.model.FileInfoB\x0b\n\tparameter\"j\n\x0f\x43ommandResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12(\n\tdatapoint\x18\x03 \x01(\x0b\x32\x13.v1.model.DatapointH\x00\x42\x08\n\x06result\"1\n\x08\x46ileInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\"?\n\x10\x43ommandsMetadata\x12+\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x19.v1.model.CommandMetadata\"\xf2\x02\n\x0f\x43ommandMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11parameter_enabled\x18\x04 \x01(\x08\x12\x17\n\x0fparameter_value\x18\x05 \x01(\t\x12\x44\n\x0eparameter_meta\x18\x06 \x03(\x0b\x32,.v1.model.CommandMetadata.ParameterMetaEntry\x12\x0f\n\x07\x65nabled\x18\x07 \x01(\x08\x12\n\n\x02id\x18\x08 \x01(\t\x12\x31\n\x04tags\x18\t \x03(\x0b\x32#.v1.model.CommandMetadata.TagsEntry\x1a\x34\n\x12ParameterMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_datapoint__pb2.DESCRIPTOR,])




_COMMANDREQUEST = _descriptor.Descriptor(
  name='CommandRequest',
  full_name='v1.model.CommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.CommandRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='v1.model.CommandRequest.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='v1.model.CommandRequest.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scrubber_time', full_name='v1.model.CommandRequest.scrubber_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files', full_name='v1.model.CommandRequest.files', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parameter', full_name='v1.model.CommandRequest.parameter',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=111,
  serialized_end=271,
)


_COMMANDRESPONSE = _descriptor.Descriptor(
  name='CommandResponse',
  full_name='v1.model.CommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='v1.model.CommandResponse.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='v1.model.CommandResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datapoint', full_name='v1.model.CommandResponse.datapoint', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='v1.model.CommandResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=273,
  serialized_end=379,
)


_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='v1.model.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.FileInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.FileInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='v1.model.FileInfo.url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=381,
  serialized_end=430,
)


_COMMANDSMETADATA = _descriptor.Descriptor(
  name='CommandsMetadata',
  full_name='v1.model.CommandsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='v1.model.CommandsMetadata.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=495,
)


_COMMANDMETADATA_PARAMETERMETAENTRY = _descriptor.Descriptor(
  name='ParameterMetaEntry',
  full_name='v1.model.CommandMetadata.ParameterMetaEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.CommandMetadata.ParameterMetaEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.CommandMetadata.ParameterMetaEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=823,
)

_COMMANDMETADATA_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.CommandMetadata.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.CommandMetadata.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.CommandMetadata.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=825,
  serialized_end=868,
)

_COMMANDMETADATA = _descriptor.Descriptor(
  name='CommandMetadata',
  full_name='v1.model.CommandMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.CommandMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='v1.model.CommandMetadata.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='v1.model.CommandMetadata.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter_enabled', full_name='v1.model.CommandMetadata.parameter_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter_value', full_name='v1.model.CommandMetadata.parameter_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter_meta', full_name='v1.model.CommandMetadata.parameter_meta', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='v1.model.CommandMetadata.enabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.CommandMetadata.id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.CommandMetadata.tags', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDMETADATA_PARAMETERMETAENTRY, _COMMANDMETADATA_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=868,
)

_COMMANDREQUEST.fields_by_name['scrubber_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMANDREQUEST.fields_by_name['files'].message_type = _FILEINFO
_COMMANDREQUEST.oneofs_by_name['parameter'].fields.append(
  _COMMANDREQUEST.fields_by_name['text'])
_COMMANDREQUEST.fields_by_name['text'].containing_oneof = _COMMANDREQUEST.oneofs_by_name['parameter']
_COMMANDRESPONSE.fields_by_name['datapoint'].message_type = protos_dot_model_dot_v1_dot_datapoint__pb2._DATAPOINT
_COMMANDRESPONSE.oneofs_by_name['result'].fields.append(
  _COMMANDRESPONSE.fields_by_name['datapoint'])
_COMMANDRESPONSE.fields_by_name['datapoint'].containing_oneof = _COMMANDRESPONSE.oneofs_by_name['result']
_COMMANDSMETADATA.fields_by_name['commands'].message_type = _COMMANDMETADATA
_COMMANDMETADATA_PARAMETERMETAENTRY.containing_type = _COMMANDMETADATA
_COMMANDMETADATA_TAGSENTRY.containing_type = _COMMANDMETADATA
_COMMANDMETADATA.fields_by_name['parameter_meta'].message_type = _COMMANDMETADATA_PARAMETERMETAENTRY
_COMMANDMETADATA.fields_by_name['tags'].message_type = _COMMANDMETADATA_TAGSENTRY
DESCRIPTOR.message_types_by_name['CommandRequest'] = _COMMANDREQUEST
DESCRIPTOR.message_types_by_name['CommandResponse'] = _COMMANDRESPONSE
DESCRIPTOR.message_types_by_name['FileInfo'] = _FILEINFO
DESCRIPTOR.message_types_by_name['CommandsMetadata'] = _COMMANDSMETADATA
DESCRIPTOR.message_types_by_name['CommandMetadata'] = _COMMANDMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommandRequest = _reflection.GeneratedProtocolMessageType('CommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDREQUEST,
  '__module__' : 'protos.model.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.CommandRequest)
  })
_sym_db.RegisterMessage(CommandRequest)

CommandResponse = _reflection.GeneratedProtocolMessageType('CommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDRESPONSE,
  '__module__' : 'protos.model.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.CommandResponse)
  })
_sym_db.RegisterMessage(CommandResponse)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'protos.model.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

CommandsMetadata = _reflection.GeneratedProtocolMessageType('CommandsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSMETADATA,
  '__module__' : 'protos.model.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.CommandsMetadata)
  })
_sym_db.RegisterMessage(CommandsMetadata)

CommandMetadata = _reflection.GeneratedProtocolMessageType('CommandMetadata', (_message.Message,), {

  'ParameterMetaEntry' : _reflection.GeneratedProtocolMessageType('ParameterMetaEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMMANDMETADATA_PARAMETERMETAENTRY,
    '__module__' : 'protos.model.v1.commands_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.CommandMetadata.ParameterMetaEntry)
    })
  ,

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMMANDMETADATA_TAGSENTRY,
    '__module__' : 'protos.model.v1.commands_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.CommandMetadata.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _COMMANDMETADATA,
  '__module__' : 'protos.model.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.CommandMetadata)
  })
_sym_db.RegisterMessage(CommandMetadata)
_sym_db.RegisterMessage(CommandMetadata.ParameterMetaEntry)
_sym_db.RegisterMessage(CommandMetadata.TagsEntry)


DESCRIPTOR._options = None
_COMMANDMETADATA_PARAMETERMETAENTRY._options = None
_COMMANDMETADATA_TAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)
